<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="zh_CN">
<context>
    <name>notification::BubbleItem</name>
    <message>
        <location filename="../bubblemodel.cpp" line="327"/>
        <source>1 new message</source>
        <translation>一条新消息</translation>
    </message>
</context>
</TS>